@@ -64,28 +64,17 @@ static int
 virStorageAdapterParseXMLFCHost(xmlNodePtr node,
                                 virStorageAdapterFCHost *fchost)
 {
-    char *managed = NULL;
+    if (virXMLPropTristateBool(node, "managed", VIR_XML_PROP_NONE,
+                               &fchost->managed) < 0)
+        return -1;
 
     fchost->parent = virXMLPropString(node, "parent");
-    if ((managed = virXMLPropString(node, "managed"))) {
-        int value;
-        if ((value = virTristateBoolTypeFromString(managed)) < 0) {
-            virReportError(VIR_ERR_CONFIG_UNSUPPORTED,
-                           _("unknown fc_host managed setting '%s'"),
-                           managed);
-            VIR_FREE(managed);
-            return -1;
-        }
-        fchost->managed = value;
-    }
-
     fchost->parent_wwnn = virXMLPropString(node, "parent_wwnn");
     fchost->parent_wwpn = virXMLPropString(node, "parent_wwpn");
     fchost->parent_fabric_wwn = virXMLPropString(node, "parent_fabric_wwn");
     fchost->wwpn = virXMLPropString(node, "wwpn");
     fchost->wwnn = virXMLPropString(node, "wwnn");
 
-    VIR_FREE(managed);
     return 0;
 }
 
@@ -179,39 +168,29 @@ virStorageAdapterParseXML(virStorageAdapter *adapter,
                           xmlNodePtr node,
                           xmlXPathContextPtr ctxt)
 {
-    int ret = -1;
+    int type;
     VIR_XPATH_NODE_AUTORESTORE(ctxt)
-    char *adapter_type = NULL;
 
     ctxt->node = node;
 
-    if ((adapter_type = virXMLPropString(node, "type"))) {
-        if ((adapter->type =
-             virStorageAdapterTypeFromString(adapter_type)) <= 0) {
-            virReportError(VIR_ERR_CONFIG_UNSUPPORTED,
-                           _("Unknown pool adapter type '%s'"),
-                           adapter_type);
-            goto cleanup;
-        }
+    if ((type = virXMLPropEnum(node, "type",
+                               virStorageAdapterTypeFromString,
+                               VIR_XML_PROP_NONZERO, &adapter->type)) < 0)
+        return -1;
 
-        if ((adapter->type == VIR_STORAGE_ADAPTER_TYPE_FC_HOST) &&
-            (virStorageAdapterParseXMLFCHost(node, &adapter->data.fchost)) < 0)
-                goto cleanup;
+    if (type == 0)
+        return virStorageAdapterParseXMLLegacy(node, ctxt, adapter);
 
-        if ((adapter->type == VIR_STORAGE_ADAPTER_TYPE_SCSI_HOST) &&
-            (virStorageAdapterParseXMLSCSIHost(node, ctxt,
-                                               &adapter->data.scsi_host)) < 0)
-                goto cleanup;
-    } else {
-        if (virStorageAdapterParseXMLLegacy(node, ctxt, adapter) < 0)
-            goto cleanup;
-    }
+    if ((adapter->type == VIR_STORAGE_ADAPTER_TYPE_FC_HOST) &&
+        (virStorageAdapterParseXMLFCHost(node, &adapter->data.fchost)) < 0)
+        return -1;
 
-    ret = 0;
+    if ((adapter->type == VIR_STORAGE_ADAPTER_TYPE_SCSI_HOST) &&
+        (virStorageAdapterParseXMLSCSIHost(node, ctxt,
+                                           &adapter->data.scsi_host)) < 0)
+        return -1;
 
- cleanup:
-    VIR_FREE(adapter_type);
-    return ret;
+    return 0;
 }
 
 
