@@ -20,7 +20,7 @@
  */
 
 #ifndef LIBVIRT_QEMU_PROCESSPRIV_H_ALLOW
-# error "qemu_process_priv.h may only be included by qemu_process.c or test suites"
+# error "qemu_processpriv.h may only be included by qemu_process.c or test suites"
 #endif /* LIBVIRT_QEMU_PROCESSPRIV_H_ALLOW */
 
 #pragma once
