@@ -613,9 +613,7 @@ int
 virFirewallApply(virFirewall *firewall)
 {
     size_t i, j;
-    int ret = -1;
-
-    virMutexLock(&ruleLock);
+    VIR_LOCK_GUARD lock = virLockGuardLock(&ruleLock);
 
     if (!firewall || firewall->err) {
         int err = EINVAL;
@@ -624,7 +622,7 @@ virFirewallApply(virFirewall *firewall)
             err = firewall->err;
 
         virReportSystemError(err, "%s", _("Unable to create rule"));
-        goto cleanup;
+        return -1;
     }
 
     VIR_DEBUG("Applying groups for %p", firewall);
@@ -657,13 +655,10 @@ virFirewallApply(virFirewall *firewall)
 
             virErrorRestore(&saved_error);
             VIR_DEBUG("Done rolling back groups for %p", firewall);
-            goto cleanup;
+            return -1;
         }
     }
     VIR_DEBUG("Done applying groups for %p", firewall);
 
-    ret = 0;
- cleanup:
-    virMutexUnlock(&ruleLock);
-    return ret;
+    return 0;
 }
