@@ -107,12 +107,9 @@ virNumaNodesetIsAvailable(virBitmap *nodeset)
 char *
 virTPMCreateCancelPath(const char *devpath)
 {
-    char *path;
     (void)devpath;
 
-    path = g_strdup("/sys/class/misc/tpm0/device/cancel");
-
-    return path;
+    return g_strdup("/sys/class/misc/tpm0/device/cancel");
 }
 
 /**
@@ -266,7 +263,6 @@ qemuOpenChrChardevUNIXSocket(const virDomainChrSourceDef *dev G_GNUC_UNUSED)
 
 int
 qemuBuildTPMOpenBackendFDs(const char *tpmdev G_GNUC_UNUSED,
-                           const char *cancel_path G_GNUC_UNUSED,
                            int *tpmfd,
                            int *cancelfd)
 {
