@@ -826,7 +826,7 @@ int virTestMain(int argc,
         fprintf(stderr, "Usage: %s\n", argv[0]);
         fputs("effective environment variables:\n"
               "VIR_TEST_VERBOSE set to show names of individual tests\n"
-              "VIR_TEST_DEBUG set to show information for debugging failures",
+              "VIR_TEST_DEBUG set to show information for debugging failures\n",
               stderr);
         return EXIT_FAILURE;
     }
