@@ -22,18 +22,32 @@
 
 #include "vsh.h"
 
-char ** virshAllocpagesPagesizeCompleter(vshControl *ctl,
-                                         const vshCmd *cmd,
-                                         unsigned int flags);
+char **
+virshAllocpagesPagesizeCompleter(vshControl *ctl,
+                                 const vshCmd *cmd,
+                                 unsigned int flags);
 
-char ** virshCellnoCompleter(vshControl *ctl,
+char **
+virshCellnoCompleter(vshControl *ctl,
+                     const vshCmd *cmd,
+                     unsigned int flags);
+
+char **
+virshNodeCpuCompleter(vshControl *ctl,
+                      const vshCmd *cmd,
+                      unsigned int flags);
+
+char **
+virshNodeSuspendTargetCompleter(vshControl *ctl,
+                                const vshCmd *cmd,
+                                unsigned int flags);
+
+char **
+virshDomainVirtTypeCompleter(vshControl *ctl,
                              const vshCmd *cmd,
                              unsigned int flags);
 
-char ** virshNodeCpuCompleter(vshControl *ctl,
-                              const vshCmd *cmd,
-                              unsigned int flags);
-
-char ** virshNodeSuspendTargetCompleter(vshControl *ctl,
-                                        const vshCmd *cmd,
-                                        unsigned int flags);
+char **
+virshArchCompleter(vshControl *ctl,
+                   const vshCmd *cmd,
+                   unsigned int flags);
